@@ -5,10 +5,10 @@ use strict;
 require DynaLoader;
 require Exporter;
 use vars qw(@ISA $VERSION @EXPORT_OK);
-$VERSION = '1.12';
+$VERSION = '1.14';
 @ISA = qw(DynaLoader Exporter);
 
-sub dl_load_flags { 0x01 }
+sub dl_load_flags { $^O =~ /hpux/ ? 0x00 : 0x01 }
 SAP::Rfc->bootstrap($VERSION);
 
 use SAP::Iface;
